@@ -554,11 +554,12 @@ static inline guint16 __gst_slow_read16_le (const guint8 * data) {
                                         } while (0)
 
 /* Float endianness conversion macros */
+#ifndef __GI_SCANNER__
 
 /* FIXME: Remove this once we depend on a GLib version with this */
 #ifndef GFLOAT_FROM_LE
 /**
- * GFLOAT_SWAP_LE_BE:
+ * GFLOAT_SWAP_LE_BE: (skip)
  * @in: input value
  *
  * Swap byte order of a 32-bit floating point value (float).
@@ -580,7 +581,7 @@ GFLOAT_SWAP_LE_BE(gfloat in)
 }
 
 /**
- * GDOUBLE_SWAP_LE_BE:
+ * GDOUBLE_SWAP_LE_BE: (skip)
  * @in: input value
  *
  * Swap byte order of a 64-bit floating point value (double).
@@ -602,28 +603,28 @@ GDOUBLE_SWAP_LE_BE(gdouble in)
 }
 
 /**
- * GDOUBLE_TO_LE:
+ * GDOUBLE_TO_LE: (skip)
  * @val: value
  *
  * Convert 64-bit floating point value (double) from native byte order into
  * little endian byte order.
  */
 /**
- * GDOUBLE_TO_BE:
+ * GDOUBLE_TO_BE: (skip)
  * @val: value
  *
  * Convert 64-bit floating point value (double) from native byte order into
  * big endian byte order.
  */
 /**
- * GDOUBLE_FROM_LE:
+ * GDOUBLE_FROM_LE: (skip)
  * @val: value
  *
  * Convert 64-bit floating point value (double) from little endian byte order
  * into native byte order.
  */
 /**
- * GDOUBLE_FROM_BE:
+ * GDOUBLE_FROM_BE: (skip)
  * @val: value
  *
  * Convert 64-bit floating point value (double) from big endian byte order
@@ -631,28 +632,28 @@ GDOUBLE_SWAP_LE_BE(gdouble in)
  */
 
 /**
- * GFLOAT_TO_LE:
+ * GFLOAT_TO_LE: (skip)
  * @val: value
  *
  * Convert 32-bit floating point value (float) from native byte order into
  * little endian byte order.
  */
 /**
- * GFLOAT_TO_BE:
+ * GFLOAT_TO_BE: (skip)
  * @val: value
  *
  * Convert 32-bit floating point value (float) from native byte order into
  * big endian byte order.
  */
 /**
- * GFLOAT_FROM_LE:
+ * GFLOAT_FROM_LE: (skip)
  * @val: value
  *
  * Convert 32-bit floating point value (float) from little endian byte order
  * into native byte order.
  */
 /**
- * GFLOAT_FROM_BE:
+ * GFLOAT_FROM_BE: (skip)
  * @val: value
  *
  * Convert 32-bit floating point value (float) from big endian byte order
@@ -682,6 +683,8 @@ GDOUBLE_SWAP_LE_BE(gdouble in)
 
 #endif /* !defined(GFLOAT_FROM_LE) */
 
+#endif /* !__GI_SCANNER__ */
+
 /**
  * GST_READ_FLOAT_LE:
  * @data: memory location
@@ -1031,6 +1034,17 @@ gboolean                gst_element_seek_simple         (GstElement   *element,
                                                          GstSeekFlags  seek_flags,
                                                          gint64        seek_pos);
 
+GST_API
+gchar *                 gst_element_decorate_stream_id  (GstElement   *element,
+                                                         const gchar  *stream_id);
+GST_API
+gchar *   gst_element_decorate_stream_id_printf_valist  (GstElement * element,
+                                                         const gchar * format,
+                                                         va_list var_args) G_GNUC_PRINTF (2, 0) G_GNUC_MALLOC;
+GST_API
+gchar *          gst_element_decorate_stream_id_printf  (GstElement * element,
+                                                         const gchar * format,
+                                                         ...) G_GNUC_PRINTF (2, 3) G_GNUC_MALLOC;
 /* util elementfactory functions */
 
 GST_API
@@ -1168,6 +1182,18 @@ typedef enum {
   GST_SEARCH_MODE_AFTER
 } GstSearchMode;
 
+/**
+ * GstPluginAPIFlags:
+ * @GST_PLUGIN_API_FLAG_IGNORE_ENUM_MEMBERS: Ignore enum members when generating
+ *   the plugins cache. This is useful if the members of the enum are generated
+ *   dynamically, in order not to expose incorrect documentation to the end user.
+ *
+ * Since: 1.18
+ */
+typedef enum {
+  GST_PLUGIN_API_FLAG_IGNORE_ENUM_MEMBERS = (1 << 0),
+} GstPluginAPIFlags;
+
 GST_API
 gpointer      gst_util_array_binary_search      (gpointer array, guint num_elements,
                                                  gsize element_size, GCompareDataFunc search_func,
@@ -1182,6 +1208,10 @@ gint          gst_util_greatest_common_divisor  (gint a, gint b);
 GST_API
 gint64        gst_util_greatest_common_divisor_int64 (gint64 a, gint64 b);
 
+GST_API
+void          gst_util_simplify_fraction        (gint *numerator, gint *denominator,
+                                                 guint n_terms, guint threshold);
+
 GST_API
 void          gst_util_fraction_to_double       (gint src_n, gint src_d, gdouble *dest);
 
@@ -1192,6 +1222,9 @@ GST_API
 gboolean      gst_util_fraction_multiply        (gint a_n, gint a_d, gint b_n, gint b_d,
                                                  gint *res_n, gint *res_d);
 GST_API
+gboolean      gst_util_fraction_multiply_int64  (gint64 a_n, gint64 a_d, gint64 b_n, gint64 b_d,
+                                                 gint64 *res_n, gint64 *res_d);
+GST_API
 gboolean      gst_util_fraction_add             (gint a_n, gint a_d, gint b_n, gint b_d,
                                                  gint *res_n, gint *res_d);
 GST_API
@@ -1204,6 +1237,20 @@ gboolean      gst_calculate_linear_regression   (const GstClockTime * xy,
                                                  GstClockTime * b, GstClockTime * xbase,
                                                  gdouble * r_squared);
 
+GST_API
+void          gst_type_mark_as_plugin_api       (GType type, GstPluginAPIFlags flags);
+
+GST_API
+gboolean      gst_type_is_plugin_api            (GType type, GstPluginAPIFlags *flags);
+
+GST_API
+guint         gst_util_ceil_log2                (guint32 v);
+
+GST_API
+guint         gst_util_floor_log2               (guint32 v);
+
+GST_API
+gint          gst_util_filename_compare        (const gchar *a, const gchar *b);
 
 G_END_DECLS
 
